#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailgeowidget
----------
A Google Maps widget for Wagtail that supports both GeoDjango PointField, StreamField and the standard CharField.
"""
__title__ = "wagtailgeowidget"
__version__ = "3.1.4"
__build__ = 314
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2015-2017 Fröjd Interactive"



from wagtail.wagtailadmin.edit_handlers import BaseFieldPanel

from wagtailgeowidget.widgets import GeoField


class GeoPanel(BaseFieldPanel):
    def __init__(self, field_name, classname="", address_field="", zoom=7):
        self.field_name = field_name
        self.classname = classname
        self.address_field = address_field
        self.zoom = zoom

    def bind_to_model(self, model):
        field = model._meta.get_field(self.field_name)

        srid = getattr(field, 'srid', 4326)

        widget = type(str('_GeoField'), (GeoField,), {
            'address_field': self.address_field,
            'zoom': self.zoom,
            'srid': srid,
            'id_prefix': 'id_',
        })

        base = {
            'model': model,
            'field_name': self.field_name,
            'classname': self.classname,
            'widget': widget,
        }

        out = type(str('_GeoPanel'), (BaseFieldPanel,), base)
        return out



import json

import six
from django.forms import HiddenInput
from django.utils.html import format_html
from django.utils.safestring import mark_safe

try:
    from django.contrib.gis.geos.point import Point
except:
    Point = None

from wagtailgeowidget.helpers import geosgeometry_str_to_struct
from wagtailgeowidget.app_settings import (
    GEO_WIDGET_DEFAULT_LOCATION,
    GEO_WIDGET_ZOOM,
    GOOGLE_MAPS_V3_APIKEY,
)


class GeoField(HiddenInput):
    address_field = None
    id_prefix = 'id_'
    srid = None

    def __init__(self, *args, **kwargs):
        self.address_field = kwargs.pop('address_field', self.address_field)
        self.srid = kwargs.pop('srid', self.srid)
        self.id_prefix = kwargs.pop('id_prefix', self.id_prefix)

        super(GeoField, self).__init__(*args, **kwargs)

    class Media:
        css = {
            'all': ('wagtailgeowidget/css/geo-field.css',)
        }

        js = (
            'wagtailgeowidget/js/geo-field.js',
            'https://maps.google.com/maps/api/js?key={}&libraries=places'
            .format(
                GOOGLE_MAPS_V3_APIKEY
            ),
        )

    def render(self, name, value, attrs=None):
        out = super(GeoField, self).render(name, value, attrs)

        location = format_html(
            '<div class="input">'
            '<input id="_id_{}_latlng" class="geo-field-location" maxlength="250" type="text">'  # NOQA
            '</div>',
            name
        )

        if '-' in name:
            namespace = name.split('-')[:-1]
            namespace = '-'.join(namespace)
            namespace = '{}-'.format(namespace)
        else:
            namespace = ''

        source_selector = '#{}{}'.format(self.id_prefix, name)
        address_selector = '#{}{}{}'.format(self.id_prefix,
                                            namespace,
                                            self.address_field)

        data = {
            'sourceSelector': source_selector,
            'defaultLocation': GEO_WIDGET_DEFAULT_LOCATION,
            'addressSelector': address_selector,
            'latLngDisplaySelector': '#_id_{}_latlng'.format(name),
            'zoom': GEO_WIDGET_ZOOM,
            'srid': self.srid,
        }

        if value and isinstance(value, six.string_types):
            result = geosgeometry_str_to_struct(value)
            if result:
                data['defaultLocation'] = {
                    'lat': result['y'],
                    'lng': result['x'],
                }

        if value and Point and isinstance(value, Point):
            data['defaultLocation'] = {
                'lat': value.y,
                'lng': value.x,
            }

        json_data = json.dumps(data)
        data_id = 'geo_field_{}_data'.format(name)

        return mark_safe(
            '<script>window["{}"] = {};</script>'.format(data_id, json_data) +
            out +
            location +
            '<div class="geo-field" data-data-id="{}"></div>'.format(data_id) +
            """
            <script>
            (function(){
                if (document.readyState === 'complete') {
                    return initializeGeoFields();
                }

                $(window).load(function() {
                    initializeGeoFields();
                });
            })();
            </script>
            """
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import re
import pip
from setuptools import setup, find_packages
from pip.req import parse_requirements


if sys.argv[-1] == "publish":
    os.system("python setup.py sdist upload")
    sys.exit()


with open('README.md') as f:
    readme = f.read()

# Handle requirements
requires = parse_requirements("requirements/install.txt",
                              session=pip.download.PipSession())
install_requires = [str(ir.req) for ir in requires]

# Convert markdown to rst
try:
    from pypandoc import convert
    long_description = convert("README.md", "rst")
except:
    long_description = ""

version = ''
with open('wagtailgeowidget/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

setup(
    name="wagtailgeowidget",
    version=version,
    description=("A Google Maps widget for Wagtail that supports both GeoDjango PointField, StreamField and CharField."),  # NOQA
    long_description=long_description,
    author="Fröjd",
    author_email="martin@marteinn.se",
    url="https://github.com/frojd/wagtail-geo-widget",
    packages=find_packages(exclude=('tests*',)),
    include_package_data=True,
    install_requires=install_requires,
    license="MIT",
    zip_safe=False,
    classifiers=[
        "Development Status :: 4 - Beta",
        'Environment :: Web Environment',
        "Intended Audience :: Developers",
        "Natural Language :: English",
        'Intended Audience :: Developers',
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        'Programming Language :: Python :: 2',
        "Programming Language :: Python :: 2.7",
        'Framework :: Django',
        'Topic :: Utilities',
    ],
)
